---
title: 'A framework for generating interactive reports for cancer genome analysis'
tags:
  - Bioimfomatics
  - Visualization
  - Cancer Genome
authors:
 - name: Ai Okada
   orcid: 0000-0002-9782-5900
   affiliation: 1
 - name: Kenichi Chiba
   affiliation: 1
 - name: Hiroko Tanaka
   affiliation: 1
 - name: Satoru Miyano
   affiliation: 1
 - name: Yuichi Shiraishi
   orcid: 0000-0001-6144-5845
   affiliation: 1
affiliations:
 - name: Laboratory of DNA Information Analysis, Human Genome Center, Institute of Medical Science, The University of Tokyo, Tokyo, Japan
   index: 1
date: 13 November 2017
bibliography: paper.bib
---

# Summary

We introduce paplot, the software for generating dynamic reports that are frequently necessary in the post analyticalphases of cancer genome studies. The "interactive" nature of the paplot-generated reportsenables users to extract much richer information than that obtained from static graphs via most conventional visualization tools.

The worldwide rapid accumulation of massive cancer genome sequencing data presents an unprecedented opportunity for obtain-ing enormous biologically and clinically important information. Several analytical tools have been developed for identifying somat-ic mutations [@koboldt2012varscan; @shiraishi2013empirical], struc-tural variations [@rausch2012delly], and prominent mutation signatures [@shiraishi2015simple] and so on. 
However, the subse-quent visualization and interpretation often demand us additional laborious efforts such as formatting and organizing the result ta-bles via additional scripting, as well as graphic manipulation via drawing tools, occasionally with multiple trial-and-error parameter adjustments. 
Additionally, as many existing tools only provide static figures [@skidmore2016genvisr; @yin2012ggbio], it is neces-sary to again repeatedly execute drawing tools with different set-tings even for generating slightly different visualizations (e.g., sorting and filtering by specific criteria). 
Furthermore, even when some interesting characteristics are observed, we often need to bother to refer back to the raw analytical result tables for identify-ing the samples and the exact values of interest, as these may not be shown in the static figures.
Here, we present [paplot](https://github.com/Genomon-Project/paplot), a suite of programs to generate various reports for commonly needed tasks in cancer genome analysis. 
paplot accepts text-based input data and configuration files and generates HTML files with dynamic, interactive data visualizations powered by [D3.js](https://d3js.org). 
By modifying settings in the configuration files, users can freely change various visual aspects such as colors of objects and contents of pop-up windows appearing after DOM events such as mouse-click and mouse-over.

Interactive graphics contain richer information than static ones, thus facilitating effective and intuitive interpretation of analytical results. 
Owing to the advancement in information technologies and development of application frameworks for easy generation of interactive graphics, using interactive graphics for academic re-search and auto-generated reports for clinical sequencing will be-come more common. 
We believe that paplot will be useful for academic research and clinical practice.

---

![Example of interactive reports created by paplot. (A) Quality Control Report. (B) Chromosomal Aberration Report. (C) Mutation Matrix Report. (D) Mutational Signature Report.](graphs.png)

## Quality Control Report

Confirming the quality of sequence data (e.g., coverage, insert size and mapping ratio) is a fundamental step in sequence analysis. In many cases, the quality control check is performed by visual in-spection of the barplot to check whether there are some samples with strangely heights. However, as adding the X-axis labels for all the samples is not always possible especially when the sample size in the cohort is large, we have to spend excessive time to retrieve the raw table data to identify the samples with the strange features. By using the Quality Control Report generated by paplot (Figure 1A), one can immediately identify such samples via pop-up con-tents.

## Chromosomal Aberration Report

Chromosomal aberrations play important roles in cancer develop-ment [@mitelman2007impact]. 
After characterizing chromosomal aberrations (genomic structural variations from whole genome sequencing data or fusion transcripts from transcriptome sequenc-ing data), it is common to generate a visual overview of chromo-somal aberrations, typically using the circos plot [@krzywinski2009circos], to examine for certain specific phenomena such as chromothripsis [@stephens2011massive]. 
When the users open the Chromosomal Aberrations Report (Figure 1B), they will first find thumbnails for chromosomal aber-rations across all the samples, thus providing a cohort-level land-scape. 
On clicking one of the thumbnails, the bigger picture of chromosomal aberrations for the sample of interest appears, and detailed information of each variant (e.g., exact coordinates of breakpoints and affected genes) pops up upon mouse-over. 
Fur-thermore, the distribution for the cumulative count of breakpoints of chromosomal aberrations partitioned by a certain chromosomal bin size (default size is 50 Kbp) is automatically generated, facili-tating identification of common cancer-driving variants represented by prominent peaks. 

## Mutation Matrix Report

Obtaining a comprehensive vision of somatic mutations across cancer genomes in a cohort of interest to examine frequencies of affected genes, relative ratio of variant types (e.g., missense, non-sense), and co-occurrence and exclusivity between two genes, is a principal goal in cancer genome analysis. 
paplot produces the Mu-tation Matrix Report (Figure 1C), a dynamic report illustrating the mutation status, which can fulfill the above purpose. Users can enjoy sorting by several criteria such as sample-wise and gene-wise frequencies. 
In addition, the user can generate a “waterfall” plot [@skidmore2016genvisr], where samples are hierarchically divided per the mutation status of genes in descending order of mutation frequencies. 
Furthermore, clinical information can be included in the plot footer, which can work as additional sort keys.

## Mutational Signature Report

In the past few years, massive genome cancer sequencing analysis revealed many characteristic patterns of somatic mutations. The profile of such mutation signature is typically represented by a bar plot with 96 possible types (6 types of substitution × 4 types of 5' base × 4 types of 3' base) [@alexandrov2013deciphering]. 
We have recently proposed another way of visualizing mutation signatures to enable the inclusion of more contextual factors [@shiraishi2015simple]. 
paplot can generate the Mutational Signature Report (Figure 1D) in both format types. Furthermore, since the barplot of mem-bership parameters (estimated fractions of operative mutation signatures for each sample) is also generated, the user can easily spot the sample with prominent mutation signatures via pop-up windows.

# Funding

This work was supported by a Grant-in-Aid from the Japan Agency for Medical Research and Development [Advanced Genome Research and Bioinformatics Study to Facilitate Medical Innovation (17km0405207h0002)] and a Grant-in-Aid for Scientific Research (KAKENHI 15H05912 and 15K00398). 

# References
